const createError = require('http-errors');
const express = require('express');
const helmet = require('helmet');
const logger = require('morgan');
const cookieParser = require('cookie-parser')
const indexRouter = require('./routes/index');
const authRouter = require('./routes/auth');
const noteRouter = require('./routes/note');

const app = express();
const port = process.env.PORT || 3000;

app.use(logger('dev'));
app.use(express.json());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser())

if(process.env.CHALLENGE_ID !== '1'){
  app.use(helmet.hsts({
    maxAge: 31536000,
    includeSubDomains: false,
    preload: false
  }))
}

app.use('/', indexRouter);
app.use('/api/auth/', authRouter);
app.use('/api/note/', noteRouter);

app.use(function(req, res, next) {
  res.status(404).send({'error': 'error'});
});

app.use((err, req, res, next) => {
  console.log(err);
  res.status(500).send({'error': 'error'});
});

app.listen(port, () => { })
