const express = require("express");
const puppeteer = require("puppeteer");
const logger = require("morgan");
const ipaddr = require("ipaddr.js");

const app = express();
const port = process.env.PORT || 3000;

const challengeIds = [1, 2, 3];
const sleep = (ms) => new Promise((resolve) => setTimeout(resolve, ms));
const FLAG = {};
const PAGE = {};
challengeIds.forEach((i) => {
  FLAG[i] = process.env[`FLAG${i}`] || "MINICTF{FLAG}";
  PAGE[i] = process.env[`PAGE${i}`] || "http://localhost:3000";
});

app.use(logger("dev"));
app.use(express.json());
app.use(express.urlencoded({ extended: false }));

var running = 0;
const MAX_INSTANCES = 5;

let browser;
puppeteer
  .launch({
    args: [
      "--incognito",
      "--no-sandbox",
      "--no-gpu",
      "--no-first-run",
      "--no-default-browser-check",
      "--no-zygote",
      "--disable-default-apps",
      "--disable-translate",
      "--disable-device-discovery-notifications",
      "--disable-gpu",
      "--disable-sync",
      "--disable-extensions",
      "--disable-software-rasterizer",
      "--disable-dev-shm-usage",
      "--disable-setuid-sandbox",
      "--disable-features=HttpsUpgrades", //MITM可能な攻撃者はアップグレードを防ぐことが出来るので標準で無効化しておく
    ],
  })
  .then((b) => (browser = b));

// 問題を解く上では、細かい実装は関係ありません。
async function doMitm(challengeId, openUrl, mitmRule) {
  try {
    // Cookieの共有を防ぐ
    const ctx = await browser.createBrowserContext();
    setTimeout(async () => {
      try {
        await ctx.close();
      } catch (e) {
      } finally {
        running -= 1;
      }
    }, 5000);
    const page = await ctx.newPage();
    const client = await page.target().createCDPSession();

    /*
     * サービスのセッションを取得してFLAGを書き込みます。
     * これをリークしてください。
     */
    const buttonSelector = "#post:not([disabled])";
    await Promise.all([
      page.waitForSelector(buttonSelector),
      page.goto(PAGE[challengeId]),
    ]);
    await page.type("#content", FLAG[challengeId]); // FLAGを書き込む
    await page.click(buttonSelector); // noteを投稿する

    await client.send("Fetch.enable", {
      patterns: [
        {
          urlPattern: "http://*",
          requestStage: "Response",
        },
      ],
    });
    await client.on("Fetch.requestPaused", async (req) => {
      const { requestId } = req;

      //307 Internal Redirect == HSTSの内部リダイレクト (これはMITM可能であっても通信経路からは書き換えられないため、書き換え対象から除外する)
      if (
        req.responseStatusCode != 307 &&
        req.request.url === mitmRule.targetUrl
      ) {
        await client.send("Fetch.fulfillRequest", {
          requestId,
          responseCode: mitmRule.responseCode,
          responseHeaders: mitmRule.responseHeaders,
          body: btoa(mitmRule.body),
        });
      } else {
        await client.send("Fetch.continueRequest", { requestId });
      }
    });

    await page.goto(openUrl);

    //このユーザーは投稿ボタンがあれば自動的に押下します
    await page.waitForSelector(buttonSelector);
    await page.click(buttonSelector);
  } catch (e) {
    console.log(e);
  }
}

app.post("/", function (req, res, next) {
  try {
    const { challengeId, url, mitmRule } = req.body;
    if (![1, 2, 3].includes(challengeId)) {
      throw Error();
    }
    const openUrl = new URL(url);
    if (openUrl.protocol !== "http:" && openUrl.protocol != "https:") {
      throw Error();
    }
    if (
      typeof mitmRule.targetUrl !== "string" ||
      typeof mitmRule.responseCode !== "number" ||
      !Array.isArray(mitmRule.responseHeaders) ||
      typeof mitmRule.body !== "string"
    ) {
      throw Error();
    }

    const targetUrl = new URL(mitmRule.targetUrl);
    // All you want (to overwrite) for exploit is me(sandbox.tokyo).
    if (!targetUrl.hostname.endsWith(".sandbox.tokyo") || targetUrl.protocol != 'http:') {
      throw Error();
    }

    mitmRule.responseHeaders.forEach((header) => {
      if (typeof header.name !== "string" || typeof header.value !== "string") {
        throw Error();
      }
    });
    if (running >= MAX_INSTANCES) {
      res.json({
        error:
          "Too Many Requests (継続的にこれが出る場合は、サーバーを増強するので連絡してください)",
      });
    } else {
      running += 1;
      doMitm(challengeId, openUrl, mitmRule);
      res.json({ success: "success" });
    }
  } catch (e) {
    console.log(e);
    res.json({ error: "error" });
  }
});

app.use(function (req, res, next) {
  res.status(404).send({ error: "error" });
});

app.use((err, req, res, next) => {
  console.log(err);
  res.status(500).send({ error: "error" });
});

app.listen(port, () => {});
